<?php

namespace App\Http\Controllers;

use Cylab\Mark\Client;
use Illuminate\Http\Request;


class MarkController extends Controller
{
    private $server;

    public function __construct() {
        $this->server = new Client();
    }

    public function status() {
        return view("app.status", ["status" => $this->server->status()]);
    }

    public function pause() {
        $this->server->pause();
        return redirect(action('MarkController@status'));
    }

    public function resume() {
        $this->server->resume();
        return redirect(action('MarkController@status'));
    }

    public function reload() {
        $this->server->reload();
        return redirect(action('MarkController@status'));
    }

    public function ranking(string $label) {
        $detectors = $this->server->activation();
        $evidences = $this->server->findEvidence($label);
        return view(
                "app.ranking", [
                    "label" => $label,
                    "evidences" => $evidences,
                    "detectors" => $detectors]);
    }

    public function rankingHome() {
        $detectors = $this->server->activation();
        $label = $detectors[0]['label'];
        return redirect('/app/ranking/' . $label);

    }

    public function extractPoints(array $evidences) : array
    {
        $points = [];
        foreach ($evidences as $evidence) {
            $points[] = new \App\TimePoint(
                    $evidence["time"],
                    $evidence["score"]);
        }
        return $points;
    }

    public function evidence(string $id)
    {
        $time_window = 3600; // in seconds

        $ev = $this->server->findEvidenceById($id);
        $since = $ev["time"] - $time_window * 1000;

        $references = [];
        foreach ($ev["references"] as $id) {
            $references[] = $this->server->findEvidenceById($id);
        }

        $history = $this->server->findEvidenceSince($ev["label"], $ev["subject"], $since);

        return view(
                'app.evidence',[
                    "evidence" => $ev,
                    "history" => $history,
                    "history_points" => $this->extractPoints($history),
                    "references" => $references]);
    }
}
